﻿using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UltraWingGridGroups
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
			this.ultraGrid1.DataSource = GenerateData();
		}

        public DataTable GenerateData()
        {
			// Declare a DataTable to contain the program generated data
			DataTable dataTable = new DataTable("TableTest");
			// Create and add a CustomerID column
			DataColumn colWork = new DataColumn("ContactName", System.Type.GetType("System.String"));
			dataTable.Columns.Add(colWork);
			// Add CustomerID column to key array and bind to DataTable
			DataColumn[] Keys = new DataColumn[1];
			Keys[0] = colWork;
			dataTable.PrimaryKey = Keys;
			// Create and add a CustomerName column
			colWork = new DataColumn("City", System.Type.GetType("System.String"));
			colWork.MaxLength = 50;
			dataTable.Columns.Add(colWork);
			// Create and add a LastOrderDate column
			colWork = new DataColumn("Country", System.Type.GetType("System.String"));
			dataTable.Columns.Add(colWork);
			// Create Fax column and add it
			colWork = new DataColumn("Fax", System.Type.GetType("System.String"));
			dataTable.Columns.Add(colWork);
			// Create Tel column and add it
			colWork = new DataColumn("Phone", System.Type.GetType("System.String"));
			dataTable.Columns.Add(colWork);
			// Add a row
			DataRow row = dataTable.NewRow();
			row["ContactName"] = "Johns Widgets";
			row["City"] = "Vienna";
			row["Country"] = "Austria";
			row["Fax"] = "011 44(161) 999 8888";
			row["Phone"] = "202-555-0184";
			dataTable.Rows.Add(row);
			// Add another row
			row = dataTable.NewRow();
			row["ContactName"] = "Fred Cruse";
			row["City"] = "London";
			row["Country"] = "UK";
			row["Fax"] = "01 - 2222 8888";
			row["Phone"] = "+1-202-555-0106";
			dataTable.Rows.Add(row);
			// Bind the table to the grid
			return dataTable;
		}

        private void button1_Click(object sender, EventArgs e)
        {
			UltraGridBand band = this.ultraGrid1.DisplayLayout.Bands[0];

			UltraGridGroup group1 = null;
			UltraGridGroup group2 = null;

			// Clear existing groups if any.
			band.Groups.Clear();

			// Add two groups with two different keys. First arguement to the Add call is
			// the key and the second arguement is the caption of the group.
			group1 = band.Groups.Add("Group1", "Address Info");
			group2 = band.Groups.Add("Group2", "Contact Info");

			// If you don't want group headers displayed, set this to false. By default 
			// it's true.
			band.GroupHeadersVisible = false;

			// Set the LevelCount to desired number of levels. Level 0 is the first row in
			// the group, while level 1 is the second row in the group and so on. Here we 
			// are going to have 2 levels.
			band.LevelCount = 2;

			// Add ContactName column to the first level (level 0) of group1 with visible 
			// position of 0 (meaning it will appear first in that level. There is only 
			// one header in this particular level level anyways.)
			group1.Columns.Add(band.Columns["ContactName"], 0, 0);

			// Add City column to second level (level 1) with visible position of 0. And 
			// also add the Country column to the same level with the visible position of 
			// 1 so that it appears after City column.
			group1.Columns.Add(band.Columns["City"], 0, 1);
			group1.Columns.Add(band.Columns["Country"], 1, 1);

			// Add Fax and Phone columns to group2 on different levels.
			group2.Columns.Add(band.Columns["Fax"], 0, 0);
			group2.Columns.Add(band.Columns["Phone"], 0, 1);

			// Prevet the users from moving groups and columns by setting AllowGroupMoving 
			// and AllowColMoving to NotAllowed.
			band.Override.AllowGroupMoving = AllowGroupMoving.NotAllowed;
			band.Override.AllowColMoving = AllowColMoving.NotAllowed;

			// One could change the various properties like RowSpacingAfter and 
			// BorderStyleRow on the Override change the appearance.
			band.Override.RowSpacingAfter = 5;
			band.Override.BorderStyleRow = Infragistics.Win.UIElementBorderStyle.Raised;
		}

		public void addColumnToGroup()
        {
			// Get the data of the grid and add new column to it, as well as some data
			var data = GenerateData();
			DataColumn colWork = new DataColumn("NewColumn", System.Type.GetType("System.String"));
			data.Columns.Add(colWork);
			foreach(DataRow row in data.Rows)
            {
				row["NewColumn"] = "new data";
            }

			// add the new data to the grid so the new column is present
			this.ultraGrid1.DataSource = data;

			// Add the column to an existing group
			var band = this.ultraGrid1.DisplayLayout.Bands[0];
			if(band.Groups.Count > 0)
            {
				band.Groups[0].Columns.Add(band.Columns["NewColumn"], 1, 1);
            }

			// If you have data coming from a server and a column might not be there when you add new column,
			// it will be best to clear existing groups, add new data to the grid and redo groups entirely
			
			//band.Groups.Clear();
			//UltraGridGroup group1 = null;
			//UltraGridGroup group2 = null;

			//// add the new groups to the grid
			//group1 = band.Groups.Add("Group1", "Address Info");
			//group2 = band.Groups.Add("Group2", "Contact Info");

			//group1.Columns.Add(band.Columns["ContactName"], 0, 0);
			//group1.Columns.Add(band.Columns["City"], 0, 1);
			//// Here we add the new column to group 1
			//group1.Columns.Add(band.Columns["NewColumn"], 1, 1);
			//group1.Columns.Add(band.Columns["Country"], 1, 1);

			//group2.Columns.Add(band.Columns["Fax"], 0, 0);
			//group2.Columns.Add(band.Columns["Phone"], 0, 1);
		}

        private void button2_Click(object sender, EventArgs e)
        {
			addColumnToGroup();
        }
    }
}
